@@ -1,7 +1,25 @@
 from typing import List, Optional
 from ddd_objects.domain.entity import Entity, ExpiredEntity
 from .value_obj import (
+    ContainerArgs,
+    ContainerCommand,
+    ContainerEnvDict,
+    DNSPolicy,
+    DockerImageName,
+    EnvVarSourceType,
+    HTTPHeader,
+    ImagePullPolicy,
+    JobStatus,
+    LabelDict,
+    LabelSelectorOperator,
+    MatchLabels,
+    NetworkScheme,
+    NodeSelectorDict,
+    PathMode,
     PayType,
+    PodResourceDict,
+    Protocol,
+    RestartPolicy,
     Value,
     Number,
     BandWidth,
@@ -9,6 +27,8 @@ from .value_obj import (
     GPUType,
     NodeName,
     Subdomain,
+    VolumeName,
+    VolumeType,
     ZoneID,
     Bool,
     Time,
@@ -628,4 +648,266 @@ class PodContainer(ExpiredEntity):
         self.init_container_info=init_container_info
         self.container_info=container_info
         self._life_time=_life_time
+        super().__init__(_life_time)
+
+class KeyToPath(Entity):
+    def __init__(
+        self,
+        key: Key,
+        path: Path,
+        mode: Optional[PathMode] = None
+    ):
+        self.key=key
+        self.path=path
+        self.mode=mode
+
+class PodSecurityContext(Entity):
+    def __init__(
+        self,
+        run_as_user: Optional[Number] = None,
+        run_as_group: Optional[Number] = None,
+        run_as_non_root: Optional[Bool] = None
+    ):
+        self.run_as_user=run_as_user
+        self.run_as_group=run_as_group
+        self.run_as_non_root=run_as_non_root
+
+class EnvVarSource(Entity):
+    def __init__(
+        self,
+        env_var_source_type: EnvVarSourceType,
+        key: Key,
+        name: Name,
+        optional: Optional[Bool] = None
+    ):
+        self.env_var_source_type=env_var_source_type
+        self.key=key
+        self.name=name
+        self.optional=optional
+
+class EnvVar(Entity):
+    def __init__(
+        self,
+        name: Name,
+        value: Optional[Value] = None,
+        value_from: Optional[EnvVarSource] = None
+    ):
+        self.name=name
+        self.value=value
+        self.value_from=value_from
+
+class VolumeSource(Entity):
+    def __init__(
+        self,
+        name: Name,
+        volume_type: VolumeType,
+        optional: Optional[Bool] = None,
+        default_mode: Optional[PathMode] = None,
+        items: Optional[List[KeyToPath]] = None
+    ):
+        self.name=name
+        self.volume_type=volume_type
+        self.optional=optional
+        self.default_mode=default_mode
+        self.items = items
+
+class VolumeSetting(Entity):
+    def __init__(
+        self,
+        volume_name: VolumeName,
+        empty_dir: Optional[Bool] = None,
+        config_map: Optional[VolumeSource] = None,
+        secret: Optional[VolumeSource] = None
+    ):
+        self.volume_name=volume_name
+        self.empty_dir=empty_dir
+        self.config_map=config_map
+        self.secret=secret
+
+class VolumeMount(Entity):
+    def __init__(
+        self,
+        name: Name,
+        mount_path: Path,
+        read_only: Optional[Bool] = None,
+        sub_path: Optional[Path] = None
+    ):
+        self.name=name
+        self.mount_path=mount_path
+        self.read_only=read_only
+        self.sub_path=sub_path
+
+class HTTPGetAction(Entity):
+    def __init__(
+        self,
+        port: Port,
+        host: Optional[IP] = None,
+        path: Optional[Path] = None,
+        http_headers: Optional[List[HTTPHeader]] = None,
+        scheme: Optional[NetworkScheme] = None
+    ):
+        self.port=port
+        self.host=host
+        self.path=path
+        self.http_headers=http_headers
+        self.scheme=scheme
+
+class GRPCAction(Entity):
+    def __init__(
+        self,
+        port: Port,
+        service: Optional[Name] = None
+    ):
+        self.port=port
+        self.service=service
+
+class TCPSocketAction(Entity):
+    def __init__(
+        self,
+        port: Port,
+        host: Optional[IP] = None
+    ):
+        self.port=port
+        self.host=host
+
+class ContainerPort(Entity):
+    def __init__(
+        self,
+        port: Port,
+        name: Optional[Name] = None,
+        protocol: Optional[Protocol] = None,
+        host_ip: Optional[IP] = None,
+        host_port: Optional[Port] = None
+    ):
+        self.port=port
+        self.name=name
+        self.protocol=protocol
+        self.host_ip=host_ip
+        self.host_port=host_port
+
+class Probe(Entity):
+    def __init__(
+        self,
+        initial_delay_seconds: Number = Number(10),
+        period_seconds: Number = Number(10),
+        success_threshold: Optional[Number] = None,
+        timeout_seconds: Number = Number(1),
+        command: Optional[List[ContainerCommand]] = None,
+        failure_threshold: Number = Number(3),
+        grpc: Optional[GRPCAction] = None,
+        http_get: Optional[HTTPGetAction] = None,
+        tcp_socket: Optional[TCPSocketAction] = None
+    ):
+        self.initial_delay_seconds=initial_delay_seconds
+        self.period_seconds=period_seconds
+        self.success_threshold=success_threshold
+        self.timeout_seconds=timeout_seconds
+        self.command=command
+        self.failure_threshold=failure_threshold
+        self.grpc=grpc
+        self.http_get=http_get
+        self.tcp_socket=tcp_socket
+
+class LabelSelectorRequirement(Entity):
+    def __init__(
+        self,
+        key: Key,
+        operator: LabelSelectorOperator,
+        values: Optional[List[Value]] = None
+    ):
+        self.key=key
+        self.operator=operator
+        self.values=values
+
+class LabelSelector(Entity):
+    def __init__(
+        self,
+        match_expressions: Optional[List[LabelSelectorRequirement]],
+        match_labels: Optional[MatchLabels],
+    ):
+        self.match_expressions = match_expressions
+        self.match_labels=match_labels
+
+class ContainerSetting(Entity):
+    def __init__(
+        self,
+        container_name: Name,
+        container_image: DockerImageName,
+        env_vars: Optional[ContainerEnvDict],
+        command: Optional[ContainerCommand],
+        args: Optional[ContainerArgs],
+        image_pull_policy: Optional[ImagePullPolicy],
+        working_dir: Optional[Path],
+        volume_mount: Optional[List[VolumeMount]],
+        security_context: Optional[PodSecurityContext],
+        limits: Optional[PodResourceDict],
+        requests: Optional[PodResourceDict],
+        readiness_probe: Optional[Probe],
+        liveness_probe: Optional[Probe],
+        ports: Optional[List[ContainerPort]]
+    ):
+        self.container_name = container_name
+        self.container_image = container_image
+        self.env_vars = env_vars
+        self.command = command
+        self.args = args
+        self.image_pull_policy = image_pull_policy
+        self.working_dir = working_dir
+        self.volume_mount = volume_mount
+        self.security_context = security_context
+        self.limits = limits
+        self.requests = requests
+        self.readiness_probe = readiness_probe
+        self.liveness_probe = liveness_probe
+        self.ports = ports
+
+class JobSetting(Entity):
+    def __init__(
+        self,
+        job_name: Name,
+        namespace_name: Name,
+        labels: LabelDict,
+        containers: List[ContainerSetting],
+        init_containers: Optional[List[ContainerSetting]],
+        parallelism: Number = Number(1),
+        ttl_seconds_after_finished: Number = Number(600),
+        restart_policy: RestartPolicy = RestartPolicy('Never'),
+        backoff_limit: Number = Number(2),
+        node_name: Optional[Name] = None,
+        node_selector: Optional[NodeSelectorDict] = None,
+        volumes: Optional[List[VolumeSetting]] = None,
+        selector: Optional[LabelSelector] = None,
+        dns_policy: Optional[DNSPolicy] = None
+    ):
+        self.job_name = job_name
+        self.namespace_name = namespace_name
+        self.labels = labels
+        self.containers = containers
+        self.init_containers = init_containers
+        self.parallelism = parallelism
+        self.ttl_seconds_after_finished = ttl_seconds_after_finished
+        self.restart_policy = restart_policy
+        self.backoff_limit = backoff_limit
+        self.node_name = node_name
+        self.node_selector = node_selector
+        self.volumes = volumes
+        self.selector = selector
+        self.dns_policy = dns_policy
+
+class Job(ExpiredEntity):
+    def __init__(
+        self,
+        name: Name,
+        age: DateTime,
+        namespace: Name,
+        status: JobStatus,
+        parallelism: Number,
+        _life_time: Number = Number(5)
+    ):
+        self.name=name
+        self.age=age
+        self.namespace=namespace
+        self.status=status
+        self.parallelism=parallelism
+        self._life_time=_life_time
         super().__init__(_life_time)
\ No newline at end of file
