@@ -10,6 +10,14 @@ class Number(ExpiredValueObject):
             raise FormatError(f'The given value ({value}) is not a Number')
         super().__init__(value, None)
 
+class Integer(ExpiredValueObject):
+    def __init__(self, value):
+        try:
+            value = int(value)
+        except:
+            raise FormatError(f'The given value ({value}) is not a Number')
+        super().__init__(value, None)
+
 class Size(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
