@@ -12,6 +12,8 @@ from .do import (
     IngressDO,
     InstanceInfoDO,
     InstanceTypeWithStatusDO,
+    JobDO,
+    JobSettingDO,
     NamespaceDO,
     NodeInfoDO,
     NodeMetaDO, 
@@ -126,7 +128,10 @@ class K3SController:
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        return [NamespaceDO(**namespace) for namespace in infos]
+        if infos is None:
+            return None
+        else:
+            return [NamespaceDO(**namespace) for namespace in infos]
 
     @exception_class_dec(max_try=1)
     def create_namespace(self, cluster_name: str, namespace_name: str, timeout=30):
@@ -160,7 +165,10 @@ class K3SController:
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        return [SecretDO(**s) for s in infos]
+        if infos is None:
+            return None
+        else:
+            return [SecretDO(**s) for s in infos]
 
     @exception_class_dec(max_try=1)
     def create_config_maps(
@@ -185,7 +193,10 @@ class K3SController:
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        return [ConfigMapDO(**s) for s in infos]
+        if infos is None:
+            return None
+        else:
+            return [ConfigMapDO(**s) for s in infos]
 
     @exception_class_dec(max_try=1)
     def create_resource_from_oss(self, cluster_name:str, target_paths:List[str], timeout=60):
@@ -218,7 +229,10 @@ class K3SController:
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        return [DeploymentDO(**s) for s in infos]
+        if infos is None:
+            return None
+        else:
+            return [DeploymentDO(**s) for s in infos]
 
     @exception_class_dec(max_try=1)
     def get_ingresses(self, cluster_name:str, namespace_name:str, timeout=30):
@@ -227,7 +241,10 @@ class K3SController:
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        return [IngressDO(**s) for s in infos]
+        if infos is None:
+            return None
+        else:
+            return [IngressDO(**s) for s in infos]
 
     @exception_class_dec(max_try=1)
     def get_pods(self, cluster_name:str, namespace_name:str, timeout=30):
@@ -236,7 +253,10 @@ class K3SController:
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        return [PodDO(**s) for s in infos]
+        if infos is None:
+            return None
+        else:
+            return [PodDO(**s) for s in infos]
 
     @exception_class_dec(max_try=1)
     def delete_pod(self, cluster_name:str, namespace_name:str, pod_name:str, timeout=5):
@@ -264,7 +284,10 @@ class K3SController:
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        return [ServiceDO(**s) for s in infos]
+        if infos is None:
+            return None
+        else:
+            return [ServiceDO(**s) for s in infos]
 
     @exception_class_dec(max_try=1)
     def get_pod_containers(self, cluster_name:str, namespace_name:str, timeout=30):
@@ -273,7 +296,51 @@ class K3SController:
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        return [PodContainerDO(**s) for s in infos]
+        if infos is None:
+            return None
+        else:
+            return [PodContainerDO(**s) for s in infos]
+
+    @exception_class_dec(max_try=1)
+    def get_jobs(self, cluster_name:str, namespace_name:str, timeout=10):
+        response=requests.get(
+            f'{self.url}/jobs/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
+            headers=self.header, timeout=timeout)
+        infos = json.loads(response.text)
+        self._check_error(response.status_code, infos)
+        if infos is None:
+            return None
+        else:
+            return [JobDO(**s) for s in infos]
+        
+    @exception_class_dec(max_try=1)
+    def create_job(self, cluster_name:str, job_setting:JobSettingDO, timeout=10):
+        data = json.dumps(job_setting.to_json())
+        response=requests.post(
+            f'{self.url}/job/cluster_name/{cluster_name}', 
+            headers=self.header, data=data, timeout=timeout)
+        info = json.loads(response.text)
+        self._check_error(response.status_code, info)
+        if info is None:
+            return None
+        else:
+            return JobDO(**info)
+    
+    @exception_class_dec(max_try=1)
+    def get_pod_log(
+        self, 
+        cluster_name:str,
+        namespace_name:str,
+        pod_name:str,
+        tail_lines:int,
+        timeout:int=10
+    ):
+        response=requests.get(
+            f'{self.url}/log/cluster_name/{cluster_name}/namespace_name/{namespace_name}/pod_name/{pod_name}/tail_lines/{tail_lines}', 
+            headers=self.header, timeout=timeout)
+        info = json.loads(response.text)
+        self._check_error(response.status_code, info)
+        return info
 
 
 repo_info = \
