@@ -1,11 +1,23 @@
-from shutil import disk_usage
 from typing import List
 from ddd_objects.infrastructure.converter import Converter
 from ..domain.entity import (
+    ContainerPort,
+    ContainerSetting,
     DNSRecord,
+    EnvVar,
+    EnvVarSource,
+    GRPCAction,
+    HTTPGetAction,
+    Job,
+    JobSetting,
+    KeyToPath,
+    LabelSelector,
+    LabelSelectorRequirement,
     NodeInfo,
     NodeUserSetting,
     Pod,
+    PodSecurityContext,
+    Probe,
     SecretUserSetting,
     Namespace,
     ConfigMap,
@@ -25,10 +37,23 @@ from ..domain.entity import (
     Service,
     InstanceTypeUserSetting,
     PodOSSOperationInfo,
-    Ingress
+    Ingress,
+    TCPSocketAction,
+    VolumeMount,
+    VolumeSetting,
+    VolumeSource
 )
 from ..domain.value_obj import (
+    ContainerCommand,
+    EnvVarSourceType,
+    HTTPHeader,
+    JobStatus,
+    LabelSelectorOperator,
+    MatchLabels,
+    NetworkScheme,
+    PathMode,
     PayType,
+    Protocol,
     Value,
     Number,
     BandWidth,
@@ -36,6 +61,8 @@ from ..domain.value_obj import (
     GPUType,
     NodeName,
     Subdomain,
+    VolumeName,
+    VolumeType,
     ZoneID,
     Bool,
     Time,
@@ -83,7 +110,20 @@ from ..domain.value_obj import (
     Status
 )
 from .do import (
+    ContainerPortDO,
+    ContainerSettingDO,
+    EnvVarDO,
+    EnvVarSourceDO,
+    GRPCActionDO,
+    HTTPGetActionDO,
     InstanceTypeUserSettingDO,
+    JobDO,
+    JobSettingDO,
+    KeyToPathDO,
+    LabelSelectorDO,
+    LabelSelectorRequirementDO,
+    PodSecurityContextDO,
+    ProbeDO,
     SecretDO,
     NamespaceDO,
     DNSRecordDO,
@@ -106,7 +146,11 @@ from .do import (
     OSSOperationInfoDO,
     NodeMetaDO,
     ResourceOSSSettingDO,
-    ConditionDO
+    ConditionDO,
+    TCPSocketActionDO,
+    VolumeMountDO,
+    VolumeSettingDO,
+    VolumeSourceDO
 )
 
 class ConditionConverter(Converter):
@@ -701,4 +745,297 @@ class PodContainerConverter(Converter):
             init_container_info = None if x.init_container_info is None else x.init_container_info.get_value(),
             container_info = None if x.container_info is None else x.container_info.get_value(),
             _life_time = None if x._life_time is None else x._life_time.get_value()
+        )
+
+class KeyToPathConverter(Converter):
+    def to_entity(self, do: KeyToPathDO):
+        return KeyToPath(
+            key = Key(do.key),
+            path = Path(do.path),
+            mode = PathMode(do.mode)
+        )
+    def to_do(self, x: KeyToPath):
+        return KeyToPathDO(
+            key = None if x.key is None else x.key.get_value(),
+            path = None if x.path is None else x.path.get_value(),
+            mode = None if x.mode is None else x.mode.get_value()
+        )
+key_to_path_converter = KeyToPathConverter()
+
+class PodSecurityContextConverter(Converter):
+    def to_entity(self, do: PodSecurityContextDO):
+        return PodSecurityContext(
+            run_as_user = Number(do.run_as_user),
+            run_as_group = Number(do.run_as_group),
+            run_as_non_root = Bool(do.run_as_non_root)
+        )
+    def to_do(self, x: PodSecurityContext):
+        return PodSecurityContextDO(
+            run_as_user = None if x.run_as_user is None else x.run_as_user.get_value(),
+            run_as_group = None if x.run_as_group is None else x.run_as_group.get_value(),
+            run_as_non_root = None if x.run_as_non_root is None else x.run_as_non_root.get_value()
+        )
+pod_security_context_converter = PodSecurityContextConverter()
+
+class EnvVarSourceConverter(Converter):
+    def to_entity(self, do: EnvVarSourceDO):
+        return EnvVarSource(
+            env_var_source_type = EnvVarSourceType(do.env_var_source_type),
+            key = Key(do.key),
+            name = Name(do.name),
+            optional = Bool(do.optional)
+        )
+    def to_do(self, x: EnvVarSource):
+        return EnvVarSourceDO(
+            env_var_source_type = None if x.env_var_source_type is None else x.env_var_source_type.get_value(),
+            key = None if x.key is None else x.key.get_value(),
+            name = None if x.name is None else x.name.get_value(),
+            optional = None if x.optional is None else x.optional.get_value()
+        )
+env_var_source_converter = EnvVarSourceConverter()
+
+class EnvVarConverter(Converter):
+    def to_entity(self, do: EnvVarDO):
+        return EnvVar(
+            name = Name(do.name),
+            value = Value(do.value),
+            value_from = None if do.value_from is None else env_var_source_converter.to_entity(do.value_from)
+        )
+    def to_do(self, x: EnvVar):
+        return EnvVarDO(
+            name = None if x.name is None else x.name.get_value(),
+            value = None if x.value is None else x.value.get_value(),
+            value_from = None if x.value_from is None else env_var_source_converter.to_do(x.value_from)
+        )
+env_var_converter = EnvVarConverter()
+
+class VolumeSourceConverter(Converter):
+    def to_entity(self, do: VolumeSourceDO):
+        return VolumeSource(
+            name = Name(do.name),
+            volume_type = VolumeType(do.volume_type),
+            optional = Bool(do.optional),
+            default_mode = PathMode(do.default_mode),
+            items = None if do.items is None else [key_to_path_converter.to_entity(i) for i in do.items]
+        )
+    def to_do(self, x: VolumeSource):
+        return VolumeSourceDO(
+            name = None if x.name is None else x.name.get_value(),
+            volume_type = None if x.volume_type is None else x.volume_type.get_value(),
+            optional = None if x.optional is None else x.optional.get_value(),
+            default_mode = None if x.default_mode is None else x.default_mode.get_value(),
+            items = None if x.items is None else [key_to_path_converter.to_do(i) for i in x.items]
+        )
+volume_source_converter = VolumeSourceConverter()
+
+class VolumeSettingConverter(Converter):
+    def to_entity(self, do: VolumeSettingDO):
+        return VolumeSetting(
+            volume_name = VolumeName(do.volume_name),
+            empty_dir = Bool(do.empty_dir),
+            config_map= None if do.config_map is None else volume_source_converter.to_entity(do.config_map),
+            secret = None if do.secret is None else volume_source_converter.to_entity(do.secret)
+        )
+    def to_do(self, x: VolumeSetting):
+        return VolumeSettingDO(
+            volume_name = None if x.volume_name is None else x.volume_name.get_value(),
+            empty_dir = None if x.empty_dir is None else x.empty_dir.get_value(),
+            config_map = None if x.config_map is None else volume_source_converter.to_do(x.config_map),
+            secret = None if x.secret is None else volume_source_converter.to_do(x.secret)
+        )
+volume_setting_converter = VolumeSettingConverter()
+
+class VolumeMountConverter(Converter):
+    def to_entity(self, do: VolumeMountDO):
+        return VolumeMount(
+            name = Name(do.name),
+            mount_path = Path(do.mount_path),
+            read_only = Bool(do.read_only),
+            sub_path = Path(do.sub_path)
+        )
+    def to_do(self, x: VolumeMount):
+        return VolumeMountDO(
+            name = None if x.name is None else x.name.get_value(),
+            mount_path = None if x.mount_path is None else x.mount_path.get_value(),
+            read_only = None if x.read_only is None else x.read_only.get_value(),
+            sub_path = None if x.sub_path is None else x.sub_path.get_value()
+        )
+volume_mount_converter = VolumeMountConverter()
+
+class HTTPGetActionConverter(Converter):
+    def to_entity(self, do: HTTPGetActionDO):
+        return HTTPGetAction(
+            port = Port(do.port),
+            host = IP(do.host),
+            path = Path(do.path),
+            http_headers = [HTTPHeader(m) for m in do.http_headers],
+            scheme = NetworkScheme(do.scheme)
+        )
+    def to_do(self, x: HTTPGetAction):
+        return HTTPGetActionDO(
+            port = None if x.port is None else x.port.get_value(),
+            host = None if x.host is None else x.host.get_value(),
+            path = None if x.path is None else x.path.get_value(),
+            http_headers = None if x.http_headers is None else [m.get_value() for m in x.http_headers],
+            scheme = None if x.scheme is None else x.scheme.get_value()
+        )
+http_get_action_converter = HTTPGetActionConverter()
+
+class GRPCActionConverter(Converter):
+    def to_entity(self, do: GRPCActionDO):
+        return GRPCAction(
+            port = Port(do.port),
+            service = Name(do.service)
+        )
+    def to_do(self, x: GRPCAction):
+        return GRPCActionDO(
+            port = None if x.port is None else x.port.get_value(),
+            service = None if x.service is None else x.service.get_value()
+        )
+grpc_action_converter = GRPCActionConverter()
+
+class TCPSocketActionConverter(Converter):
+    def to_entity(self, do: TCPSocketActionDO):
+        return TCPSocketAction(
+            port = Port(do.port),
+            host = IP(do.host)
+        )
+    def to_do(self, x: TCPSocketAction):
+        return TCPSocketActionDO(
+            port = None if x.port is None else x.port.get_value(),
+            host = None if x.host is None else x.host.get_value()
+        )
+tcp_socket_action_converter = TCPSocketActionConverter()
+
+class ContainerPortConverter(Converter):
+    def to_entity(self, do: ContainerPortDO):
+        return ContainerPort(
+            port = Port(do.port),
+            name = Name(do.name),
+            protocol = Protocol(do.protocol),
+            host_ip = IP(do.host_ip),
+            host_port = Port(do.host_port)
+        )
+    def to_do(self, x: ContainerPort):
+        return ContainerPortDO(
+            port = None if x.port is None else x.port.get_value(),
+            name = None if x.name is None else x.name.get_value(),
+            protocol = None if x.protocol is None else x.protocol.get_value(),
+            host_ip = None if x.host_ip is None else x.host_ip.get_value(),
+            host_port = None if x.host_port is None else x.host_port.get_value()
+        )
+container_port_converter = ContainerPortConverter()
+
+class ProbeConverter(Converter):
+    def to_entity(self, do: ProbeDO):
+        return Probe(
+            initial_delay_seconds = Number(do.initial_delay_seconds),
+            period_seconds = Number(do.period_seconds),
+            success_threshold = Number(do.success_threshold),
+            timeout_seconds = Number(do.timeout_seconds),
+            command = [ContainerCommand(m) for m in do.command],
+            failure_threshold = Number(do.failure_threshold),
+            grpc = None if do.grpc is None else grpc_action_converter.to_entity(do.grpc),
+            http_get = None if do.http_get is None else http_get_action_converter.to_entity(do.http_get),
+            tcp_socket = None if do.tcp_socket is None else tcp_socket_action_converter.to_entity(do.tcp_socket)
+        )
+    def to_do(self, x: Probe):
+        return ProbeDO(
+            initial_delay_seconds = None if x.initial_delay_seconds is None else x.initial_delay_seconds.get_value(),
+            period_seconds = None if x.period_seconds is None else x.period_seconds.get_value(),
+            success_threshold = None if x.success_threshold is None else x.success_threshold.get_value(),
+            timeout_seconds = None if x.timeout_seconds is None else x.timeout_seconds.get_value(),
+            command = None if x.command is None else [m.get_value() for m in x.command],
+            failure_threshold = None if x.failure_threshold is None else x.failure_threshold.get_value(),
+            grpc = None if x.grpc is None else grpc_action_converter.to_do(x.grpc),
+            http_get = None if x.http_get is None else http_get_action_converter.to_do(x.http_get),
+            tcp_socket = None if x.tcp_socket is None else tcp_socket_action_converter.to_do(x.tcp_socket)
+        )
+probe_converter = ProbeConverter()
+
+class LabelSelectorRequirementConverter(Converter):
+    def to_entity(self, do: LabelSelectorRequirementDO):
+        return LabelSelectorRequirement(
+            key = Key(do.key),
+            operator = LabelSelectorOperator(do.operator),
+            values = [Value(m) for m in do.values]
+        )
+    def to_do(self, x: LabelSelectorRequirement):
+        return LabelSelectorRequirementDO(
+            key = None if x.key is None else x.key.get_value(),
+            operator = None if x.operator is None else x.operator.get_value(),
+            values = None if x.values is None else [m.get_value() for m in x.values]
+        )
+label_selector_requirement_converter = LabelSelectorRequirementConverter()
+
+class LabelSelectorConverter(Converter):
+    def to_entity(self, do: LabelSelectorDO):
+        return LabelSelector(
+            match_labels = MatchLabels(do.match_labels),
+            match_expressions= None if do.match_expressions is None else [label_selector_requirement_converter.to_entity(i) for i in do.match_expressions]
+        )
+    def to_do(self, x: LabelSelector):
+        return LabelSelectorDO(
+            match_labels = None if x.match_labels is None else x.match_labels.get_value(),
+            match_expressions = None if x.match_expressions is None else [label_selector_requirement_converter.to_do(i) for i in x.match_expressions]
+        )
+label_selector_converter =LabelSelectorConverter()
+
+class ContainerSettingConverter(Converter):
+    def to_do(self, x: ContainerSetting):
+        return ContainerSettingDO(
+            container_name = x.container_name.get_value(),
+            container_image = x.container_image.get_value(),
+            env_vars = None if x.env_vars is None else [env_var_converter.to_do(i) for i in x.env_vars],
+            command = None if x.command is None else x.command.get_value(),
+            args = None if x.args is None else x.args.get_value(),
+            image_pull_policy = None if x.image_pull_policy is None else x.image_pull_policy.get_value(),
+            working_dir = None if x.working_dir is None else x.working_dir.get_value(),
+            volume_mount = None if x.volume_mount is None else [volume_mount_converter.to_do(i) for i in x.volume_mount],
+            security_context = None if x.security_context is None else pod_security_context_converter.to_do(x.security_context),
+            limits = None if x.limits is None else x.limits.get_value(),
+            requests = None if x.requests is None else x.requests.get_value(),
+            readiness_probe = None if x.readiness_probe is None else probe_converter.to_do(x.readiness_probe),
+            liveness_probe = None if x.liveness_probe is None else probe_converter.to_do(x.liveness_probe),
+            ports = None if x.ports is None else [container_port_converter.to_do(i) for i in x.ports]
+        )
+container_setting_converter = ContainerSettingConverter()
+
+class JobSettingConverter(Converter):
+    def to_do(self, x: JobSetting):
+        return JobSettingDO(
+            job_name = x.job_name.get_value(),
+            namespace_name = x.namespace_name.get_value(),
+            labels = x.labels.get_value(),
+            containers = [container_setting_converter.to_do(c) for c in x.containers],
+            init_containers = None if x.init_containers is None else [container_setting_converter.to_do(i) for i in x.init_containers],
+            parallelism = x.parallelism.get_value(),
+            ttl_seconds_after_finished = x.ttl_seconds_after_finished.get_value(),
+            restart_policy = x.restart_policy.get_value(),
+            backoff_limit=x.backoff_limit.get_value(),
+            node_name = None if x.node_name is None else x.node_name.get_value(),
+            node_selector = None if x.node_selector is None else x.node_selector.get_value(),
+            volumes = None if x.volumes is None else [volume_setting_converter.to_do(i) for i in x.volumes],
+            selector = None if x.selector is None else [label_selector_converter.to_do(i) for i in x.selector],
+            dns_policy = None if x.dns_policy is None else x.dns_policy.get_value()
+        )
+
+class JobConverter(Converter):
+    def to_entity(self, do: JobDO):
+        return Job(
+            name = Name(do.name),
+            age = DateTime(do.age),
+            namespace = Name(do.namespace),
+            status = JobStatus(do.status),
+            parallelism = Number(do.parallelism),
+            _life_time = Number(do._life_time)
+        )
+    def to_do(self, x: Job):
+        return JobDO(
+            name = None if x.name is None else x.name.get_value(),
+            age = None if x.age is None else x.age.get_value(),
+            namespace = None if x.namespace is None else x.namespace.get_value(),
+            status = None if x.status is None else x.status.get_value(),
+            parallelism = None if x.parallelism is None else x.parallelism.get_value(),
+            _life_time = None if x._life_time is None else x._life_time.get_value()
         )
\ No newline at end of file
