@@ -38,6 +38,7 @@ from ..domain.entity import (
     Service
 )
 from ..domain.value_obj import (
+    Integer,
     Number,
     Key,
     Bool,
@@ -487,7 +488,7 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
         cluster_name: Name, 
         namespace_name: Name, 
         pod_name: Name, 
-        tail_lines: Number = Number(500)
+        tail_lines: Integer = Integer(500)
     ) -> Optional[str]:
         cluster_name = cluster_name.get_value()
         namespace_name = namespace_name.get_value()
